Hermes::Engine.routes.draw do
  namespace :api do
    namespace :dmo do
      notify_to :applicants, api_mode: true, controller: 'activity_notification/notifications', target_type: 'hermes/applicants'
      subscribed_by :applicants, api_mode: true, controller: '/activity_notification/subscriptions_api', target_type: 'hermes/applicants'
      resources :applicants do
        member do
          get 'eligible_offers'
        end
      end
      
      resources :entities
      resources :lessor_objective_histories
      resources :housing_applications
      resources :housing_offers do
        collection do
          get 'with_validated_applications/:id', action: 'with_validated_applications_for'
          get 'with_validated_applications'
        end
        member do
          resources :pictures, only: [:create, :update, :destroy]
          get 'eligible_requests'
          get 'selected_applications'
          post 'selected_applications', to: 'housing_offers#post_selected_applications'
          get "all_applications",  to: 'housing_offers#all_applications'
          get 'history'
          get 'detailed_score'
        end
      end
      
      resources :public_housing_offers
      
      resources :housing_requests do
        collection do
          get 'clp_details'
        end
        member do
          get 'housing_request_folder'
          post 'housing_request_folder/start_treatment', to: "housing_requests#start_treatment"
        end
      end
      
      post 'required_documents/:id/send_files', to: "required_documents#send_files"
      patch 'required_documents/:id', to: "required_documents#update"
      put 'required_documents/:id', to: "required_documents#update"
      resources :lessors do
        member do
          get 'all_objectives'
          get 'active_objectives'
          get 'current_operation_names'
        end
      end
      
      resources :lessor_objectives
      resources :nuds do
        member do
          post 'send_pin_code_on_mail'
          post 'authentify_with_pin_code'
        end
      end
      resources :thresholds
      resources :contact_groups
      resources :statuses
      
      get '/nuds/sne_department_list', to: "nuds#sne_department_list"
      resources :reservation_holders
      
      get 'doc', to: "documentation#show_doc"
      get 'changelog', to: "documentation#show_changelog"
    end
  end
end